@@ -1,6 +1,7 @@
 from ._version import __author__, __author_email__, __version__
 from .formula import Formula
 from .model_matrix import ModelMatrix
+from .sugar import model_matrix
 
 __all__ = [
     '__author__',
@@ -8,4 +9,5 @@ __all__ = [
     '__version__',
     'Formula',
     'ModelMatrix',
+    'model_matrix',
 ]
