@@ -158,7 +158,7 @@ class FormulaMaterializer(metaclass=FormulaMaterializerMeta):
                 (name, values)
                 for term, scoped_terms, scoped_cols in cols
                 for name, values in scoped_cols.items()
-            ], spec=spec),
+            ], spec=spec, drop_rows=drop_rows),
             spec=spec
         )
 
@@ -265,14 +265,19 @@ class FormulaMaterializer(metaclass=FormulaMaterializerMeta):
 
     def _evaluate_factor(self, factor, spec, drop_rows):
         if factor.expr not in self.factor_cache:
-            if factor.eval_method.value == 'lookup':
-                value = self._lookup(factor.expr)
-            elif factor.eval_method.value == 'python':
-                value = self._evaluate(factor.expr, factor.metadata, spec)
-            elif factor.eval_method.value == 'literal':
-                value = EvaluatedFactor(factor, self._evaluate(factor.expr, factor.metadata, spec), kind='constant')
-            else:
-                raise FactorEvaluationError(f"Evaluation method {factor.eval_method.value} not recognised for factor {factor.expr}.")
+            try:
+                if factor.eval_method.value == 'lookup':
+                    value = self._lookup(factor.expr)
+                elif factor.eval_method.value == 'python':
+                    value = self._evaluate(factor.expr, factor.metadata, spec)
+                elif factor.eval_method.value == 'literal':
+                    value = EvaluatedFactor(factor, self._evaluate(factor.expr, factor.metadata, spec), kind='constant')
+                else:
+                    raise FactorEvaluationError(f"Evaluation method {factor.eval_method.value} not recognised for factor {factor.expr}.")
+            except FactorEvaluationError:
+                raise
+            except Exception as e:
+                raise FactorEvaluationError(f"Unable to evaluate factor `{factor}`. [{type(e).__name__}: {e}]")
 
             if not isinstance(value, EvaluatedFactor):
                 if isinstance(value, dict) and '__kind__' in value:
@@ -449,5 +454,5 @@ class FormulaMaterializer(metaclass=FormulaMaterializerMeta):
         return out
 
     @abstractmethod
-    def _combine_columns(self, cols, spec):
+    def _combine_columns(self, cols, spec, drop_rows):
         pass  # pragma: no cover
