@@ -1,6 +1,7 @@
 from .ast_node import ASTNode
 from .factor import Factor
 from .operator import Operator
+from .operator_resolver import OperatorResolver
 from .term import Term
 from .token import Token
 
@@ -9,6 +10,7 @@ __all__ = [
     'ASTNode',
     'Factor',
     'Operator',
+    'OperatorResolver',
     'Term',
     'Token'
 ]
