@@ -11,6 +11,9 @@ from formulaic.parser.algos.tokenize import tokenize
 from formulaic.parser.types import Token
 from .layered_mapping import LayeredMapping
 
+# Type checking imports (will nest under typing.TYPE_CHECKING once we no longer support Python 3.6)
+from collections.abc import Mapping
+
 
 def stateful_transform(func):
     func = functools.singledispatch(func)
@@ -65,7 +68,7 @@ def stateful_eval(expr, env, metadata, state, spec):
     # Extract the nodes of the graph that correspond to stateful transforms
     stateful_nodes = {}
     for node in ast.walk(code):
-        if isinstance(node, ast.Call) and getattr(env.get(node.func.id), '__is_stateful_transform__', False):
+        if _is_stateful_transform(node, env):
             stateful_nodes[astor.to_source(node).strip()] = node
 
     # Mutate stateful nodes to pass in state from a shared dictionary.
@@ -117,3 +120,18 @@ def sanitize_variable_names(expr, env):
                 token = Token(new_name, kind='name')
         tokens.append(token)
     return " ".join([str(t) for t in tokens])
+
+
+def _is_stateful_transform(node: ast.AST, env: Mapping):
+    """
+    Check whether a given ast.Call node enacts a stateful transform given
+    the available symbols in `env`.
+    """
+    if not isinstance(node, ast.Call):
+        return False
+
+    try:
+        func = eval(compile(astor.to_source(node.func).strip(), '', 'eval'), {}, env)  # nosec; Get function handle (assuming it exists in env)
+        return getattr(func, '__is_stateful_transform__', False)
+    except NameError:
+        return False
